# Piccolo

[![Build Status](https://travis-ci.com/piccolo-orm/piccolo.svg?branch=master)](https://travis-ci.com/piccolo-orm/piccolo)

A fast, user friendly ORM which supports asyncio.

Not production ready yet, but progressing quickly.

For more info and docs, visit https://piccolo-orm.com

To get started, follow this tutorial:

https://piccolo-orm.com/tutorial/getting-started/installing-piccolo
